--[[
AdiBags - Dragonflight
by Zottelchen
version: 1.1.8
Add various Dragonflight items to AdiBags filter groups
]]

local addonName, addon = ...
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")

local L = addon.L
local MatchIDs
local Result = {}

local function AddToSet(List)
    local Set = {}
    for _, v in ipairs(List) do
        Set[v] = true
    end
    return Set
end

local function unescape(String)
    local unescaped = tostring(String)
    unescaped = gsub(unescaped, "|c........", "") -- Remove color start.
    unescaped = gsub(unescaped, "|r", "") -- Remove color end.
    -- Result = gsub(Result, "|H.-|h(.-)|h", "%1") -- Remove links.
    -- Result = gsub(Result, "|T.-|t", "") -- Remove textures.
    -- Result = gsub(Result, "{.-}", "") -- Remove raid target icons.
    return unescaped
end


 -- Herbs
local HerbsIDs = {
191460, -- Hochenblume
191461, -- Hochenblume
191462, -- Hochenblume
191464, -- Saxifrage
191465, -- Saxifrage
191466, -- Saxifrage
191467, -- Bubble Poppy
191468, -- Bubble Poppy
191469, -- Bubble Poppy
191470, -- Writhebark
191471, -- Writhebark
191472, -- Writhebark
}

 -- Drakewatcher Manuscripts
local DrakewatcherManuscriptsIDs = {
192111, -- Renewed Proto-Drake: Red Scales
192523, -- Renewed Proto-Drake: Green Scales
196961, -- Cliffside Wylderdrake: Armor
196962, -- Cliffside Wylderdrake: Silver and Purple Armor
196963, -- Cliffside Wylderdrake: Silver and Blue Armor
196964, -- Cliffside Wylderdrake: Gold and Black Armor
196965, -- Cliffside Wylderdrake: Bronze and Teal Armor
196966, -- Cliffside Wylderdrake: Gold and Orange Armor
196967, -- Cliffside Wylderdrake: Gold and White Armor
196968, -- Cliffside Wylderdrake: Steel and Yellow Armor
196969, -- Cliffside Wylderdrake: Finned Back
196970, -- Cliffside Wylderdrake: Spiked Back
196971, -- Cliffside Wylderdrake: Spiked Brow
196972, -- Cliffside Wylderdrake: Plated Brow
196973, -- Cliffside Wylderdrake: Dual Horned Chin
196974, -- Cliffside Wylderdrake: Four Horned Chin
196975, -- Cliffside Wylderdrake: Head Fin
196976, -- Cliffside Wylderdrake: Head Mane
196977, -- Cliffside Wylderdrake: Split Head Horns
196978, -- Cliffside Wylderdrake: Small Head Spikes
196979, -- Cliffside Wylderdrake: Curled Head Horns
196980, -- Cliffside Wylderdrake: Triple Head Horns
196981, -- Cliffside Wylderdrake: Conical Head
196982, -- Cliffside Wylderdrake: Ears
196983, -- Cliffside Wylderdrake: Maned Jaw
196984, -- Cliffside Wylderdrake: Finned Jaw
196985, -- Cliffside Wylderdrake: Horned Jaw
196986, -- Cliffside Wylderdrake: Black Hair
196987, -- Cliffside Wylderdrake: Blonde Hair
196988, -- Cliffside Wylderdrake: Red Hair
196989, -- Cliffside Wylderdrake: White Hair
196990, -- Cliffside Wylderdrake: Helm
196991, -- Cliffside Wylderdrake: Black Horns
196992, -- Cliffside Wylderdrake: Heavy Horns
196993, -- Cliffside Wylderdrake: Sleek Horns
196994, -- Cliffside Wylderdrake: Short Horns
196995, -- Cliffside Wylderdrake: Spiked Horns
196996, -- Cliffside Wylderdrake: Branched Horns
196997, -- Cliffside Wylderdrake: Split Horns
196998, -- Cliffside Wylderdrake: Hook Horns
196999, -- Cliffside Wylderdrake: Swept Horns
197000, -- Cliffside Wylderdrake: Coiled Horns
197001, -- Cliffside Wylderdrake: Finned Cheek
197002, -- Cliffside Wylderdrake: Flared Cheek
197003, -- Cliffside Wylderdrake: Spiked Cheek
197004, -- Cliffside Wylderdrake: Spiked Legs
197005, -- Cliffside Wylderdrake: Horned Nose
197006, -- Cliffside Wylderdrake: Plated Nose
197007, -- Cliffside Wylderdrake: Wide Stripes Pattern
197008, -- Cliffside Wylderdrake: Narrow Stripes Pattern
197009, -- Cliffside Wylderdrake: Scaled Pattern
197010, -- Cliffside Wylderdrake: Red Scales
197011, -- Cliffside Wylderdrake: Green Scales
197012, -- Cliffside Wylderdrake: Blue Scales
197013, -- Cliffside Wylderdrake: Black Scales
197014, -- Cliffside Wylderdrake: White Scales
197015, -- Cliffside Wylderdrake: Dark Skin Variation
197016, -- Cliffside Wylderdrake: Maned Tail
197017, -- Cliffside Wylderdrake: Large Tail Spikes
197018, -- Cliffside Wylderdrake: Finned Tail
197019, -- Cliffside Wylderdrake: Blunt Spiked Tail
197020, -- Cliffside Wylderdrake: Spear Tail
197021, -- Cliffside Wylderdrake: Spiked Club Tail
197022, -- Cliffside Wylderdrake: Finned Neck
197023, -- Cliffside Wylderdrake: Maned Neck
197090, -- Highland Drake: Gold and Black Armor
197091, -- Highland Drake: Silver and Blue Armor
197093, -- Highland Drake: Silver and Purple Armor
197094, -- Highland Drake: Gold and Red Armor
197095, -- Highland Drake: Gold and White Armor
197096, -- Highland Drake: Steel and Yellow Armor
197097, -- Highland Drake: Spined Back
197098, -- Highland Drake: Finned Back
197099, -- Highland Drake: Armor
197100, -- Highland Drake: Crested Brow
197101, -- Highland Drake: Bushy Brow
197102, -- Highland Drake: Horned Chin
197103, -- Highland Drake: Maned Chin
197104, -- Highland Drake: Tapered Chin
197105, -- Highland Drake: Spined Chin
197106, -- Highland Drake: Finned Head
197107, -- Highland Drake: Triple Finned Head
197108, -- Highland Drake: Spined Head
197109, -- Highland Drake: Spiked Head
197110, -- Highland Drake: Plated Head
197111, -- Highland Drake: Maned Head
197112, -- Highland Drake: Single Horned Head
197113, -- Highland Drake: Swept Spiked Head
197114, -- Highland Drake: Multi-Horned Head
197115, -- Highland Drake: Thorned Jaw
197116, -- Highland Drake: Ears
197117, -- Highland Drake: Black Hair
197118, -- Highland Drake: Brown Hair
197119, -- Highland Drake: Helm
197120, -- Highland Drake: Ornate Helm
197121, -- Highland Drake: Tan Horns
197122, -- Highland Drake: Heavy Horns
197123, -- Highland Drake: Thorn Horns
197124, -- Highland Drake: Swept Horns
197125, -- Highland Drake: Coiled Horns
197126, -- Highland Drake: Hooked Horns
197127, -- Highland Drake: Grand Thorn Horns
197128, -- Highland Drake: Curled Back Horns
197129, -- Highland Drake: Sleek Horns
197130, -- Highland Drake: Stag Horns
197131, -- Highland Drake: Hairy Cheek
197132, -- Highland Drake: Spiked Cheek
197133, -- Highland Drake: Spined Cheek
197134, -- Highland Drake: Spiked Legs
197135, -- Highland Drake: Toothy Mouth
197136, -- Highland Drake: Taperered Nose
197137, -- Highland Drake: Spined Nose
197138, -- Highland Drake: Striped Pattern
197139, -- Highland Drake: Large Spotted Pattern
197140, -- Highland Drake: Small Spotted Pattern
197141, -- Highland Drake: Scaled Pattern
197142, -- Highland Drake: Black Scales
197143, -- Highland Drake: Green Scales
197144, -- Highland Drake: Red Scales
197145, -- Highland Drake: Bronze Scales
197146, -- Highland Drake: White Scales
197147, -- Highland Drake: Heavy Scales
197148, -- Highland Drake: Vertical Finned Tail
197149, -- Highland Drake: Club Tail
197150, -- Highland Drake: Spiked Club Tail
197151, -- Highland Drake: Spiked Tail
197152, -- Highland Drake: Hooked Tail
197153, -- Highland Drake: Bladed Tail
197154, -- Highland Drake: Spined Neck
197155, -- Highland Drake: Finned Neck
197156, -- Highland Drake: Bronze and Green Armor
197346, -- Renewed Proto-Drake: Gold and Black Armor
197347, -- Renewed Proto-Drake: Silver and Blue Armor
197348, -- Renewed Proto-Drake: Black and Red Armor
197349, -- Renewed Proto-Drake: Gold and White Armor
197350, -- Renewed Proto-Drake: Silver and Purple Armor
197351, -- Renewed Proto-Drake: Gold and Red Armor
197352, -- Renewed Proto-Drake: Steel and Yellow Armor
197353, -- Renewed Proto-Drake: Bronze and Pink Armor
197354, -- Renewed Proto-Drake: Horned Back
197355, -- Renewed Proto-Drake: Thick Spined Jaw
197356, -- Renewed Proto-Drake: Hairy Back
197357, -- Renewed Proto-Drake: Armor
197358, -- Renewed Proto-Drake: Curved Spiked Brow
197359, -- Renewed Proto-Drake: Hairy Brow
197360, -- Renewed Proto-Drake: Spined Brow
197361, -- Renewed Proto-Drake: Spiked Crest
197362, -- Renewed Proto-Drake: Spined Crest
197363, -- Renewed Proto-Drake: Maned Crest
197364, -- Renewed Proto-Drake: Short Spiked Crest
197365, -- Renewed Proto-Drake: Finned Crest
197366, -- Renewed Proto-Drake: Dual Horned Crest
197367, -- Renewed Proto-Drake: Gray Hair
197368, -- Renewed Proto-Drake: Blue Hair
197369, -- Renewed Proto-Drake: Brown Hair
197370, -- Renewed Proto-Drake: Red Hair
197371, -- Renewed Proto-Drake: Green Hair
197372, -- Renewed Proto-Drake: Purple Hair
197373, -- Renewed Proto-Drake: Helm
197374, -- Renewed Proto-Drake: Swept Horns
197375, -- Renewed Proto-Drake: Curled Horns
197376, -- Renewed Proto-Drake: Ears
197377, -- Renewed Proto-Drake: Bovine Horns
197378, -- Renewed Proto-Drake: Subtle Horns
197379, -- Renewed Proto-Drake: Impaler Horns
197380, -- Renewed Proto-Drake: Curved Horns
197381, -- Renewed Proto-Drake: Gradient Horns
197382, -- Renewed Proto-Drake: White Horns
197383, -- Renewed Proto-Drake: Heavy Horns
197384, -- Renewed Proto-Drake: Thick Spined Jaw
197385, -- Renewed Proto-Drake: Horned Jaw
197386, -- Renewed Proto-Drake: Spiked Jaw
197387, -- Renewed Proto-Drake: Thin Spined Jaw
197388, -- Renewed Proto-Drake: Finned Jaw
197389, -- Renewed Proto-Drake: Green Scales
197390, -- Renewed Proto-Drake: Blue Scales
197391, -- Renewed Proto-Drake: Bronze Scales
197392, -- Renewed Proto-Drake: Black Scales
197393, -- Renewed Proto-Drake: White Scales
197394, -- Renewed Proto-Drake: Predator Pattern
197395, -- Renewed Proto-Drake: Harrier Pattern
197396, -- Renewed Proto-Drake: Skyterror Pattern
197397, -- Renewed Proto-Drake: Heavy Scales
197398, -- Renewed Proto-Drake: Snub Snout
197399, -- Renewed Proto-Drake: Razor Snout
197400, -- Renewed Proto-Drake: Shark Snout
197401, -- Renewed Proto-Drake: Beaked Snout
197402, -- Renewed Proto-Drake: Spiked Club Tail
197403, -- Renewed Proto-Drake: Club Tail
197404, -- Renewed Proto-Drake: Finned Tail
197405, -- Renewed Proto-Drake: Maned Tail
197406, -- Renewed Proto-Drake: Spined Tail
197407, -- Renewed Proto-Drake: Spiked Throat
197408, -- Renewed Proto-Drake: Finned Throat
197577, -- Windborne Velocidrake: Bronze and Green Armor
197578, -- Windborne Velocidrake: Silver and Blue Armor
197579, -- Windborne Velocidrake: Steel and Orange Armor
197580, -- Windborne Velocidrake: Gold and Red Armor
197581, -- Windborne Velocidrake: Silver and Purple Armor
197582, -- Windborne Velocidrake: White and Pink Armor
197583, -- Windborne Velocidrake: Exposed Finned Back
197584, -- Windborne Velocidrake: Finned Back
197585, -- Windborne Velocidrake: Maned Back
197586, -- Windborne Velocidrake: Spiked Back
197587, -- Windborne Velocidrake: Feathered Back
197588, -- Windborne Velocidrake: Armor
197589, -- Windborne Velocidrake: Large Head Fin
197590, -- Windborne Velocidrake: Small Head Fin
197591, -- Windborne Velocidrake: Hairy Head
197592, -- Windborne Velocidrake: Spined Head
197593, -- Windborne Velocidrake: Feathery Head
197594, -- Windborne Velocidrake: Small Ears
197595, -- Windborne Velocidrake: Finned Ears
197596, -- Windborne Velocidrake: Horned Jaw
197597, -- Windborne Velocidrake: Black Fur
197598, -- Windborne Velocidrake: Gray Hair
197599, -- Windborne Velocidrake: Red Hair
197600, -- Windborne Velocidrake: Helm
197601, -- Windborne Velocidrake: Wavy Horns
197602, -- Windborne Velocidrake: Cluster Horns
197603, -- Windborne Velocidrake: Curved Horns
197604, -- Windborne Velocidrake: Ox Horns
197605, -- Windborne Velocidrake: Curled Horns
197606, -- Windborne Velocidrake: Swept Horns
197607, -- Windborne Velocidrake: Split Horns
197608, -- Windborne Velocidrake: Gray Horns
197609, -- Windborne Velocidrake: White Horns
197610, -- Windborne Velocidrake: Yellow Horns
197611, -- Windborne Velocidrake: Black Scales
197612, -- Windborne Velocidrake: Blue Scales
197613, -- Windborne Velocidrake: Bronze Scales
197614, -- Windborne Velocidrake: Red Scales
197615, -- Windborne Velocidrake: Teal Scales
197616, -- Windborne Velocidrake: White Scales
197617, -- Windborne Velocidrake: Heavy Scales
197618, -- Windborne Velocidrake: Long Snout
197619, -- Windborne Velocidrake: Hooked Snout
197620, -- Windborne Velocidrake: Beaked Snout
197621, -- Windborne Velocidrake: Exposed Finned Tail
197622, -- Windborne Velocidrake: Finned Tail
197623, -- Windborne Velocidrake: Spiked Tail
197624, -- Windborne Velocidrake: Club Tail
197625, -- Windborne Velocidrake: Feathery Tail
197626, -- Windborne Velocidrake: Exposed Finned Neck
197627, -- Windborne Velocidrake: Finned Neck
197628, -- Windborne Velocidrake: Plated Neck
197629, -- Windborne Velocidrake: Spiked Neck
197630, -- Windborne Velocidrake: Feathered Neck
197634, -- Windborne Velocidrake: Windswept Pattern
197635, -- Windborne Velocidrake: Reaver Pattern
197636, -- Windborne Velocidrake: Shrieker Pattern
199074, -- Studies of Arcane Magic
201790, -- Renewed Proto-Drake: Embodiment of the Storm-Eater
201792, -- Highland Drake: Embodiment of the Crimson Gladiator
}

 -- Enchanting
local EnchantingIDs = {
193057, -- 10.0 Placeholder Enchanting Crystal
194123, -- Chromatic Dust
194124, -- Vibrant Shard
200113, -- Resonant Crystal
201584, -- Serevite Rod
}

 -- Reputation Items
local ReputationItemsIDs = {
191251, -- Key Fragments
191264, -- Restored Obsidian Key
192055, -- Dragon Isles Artifact
193201, -- Key Framing
199906, -- Titan Relic
200071, -- Sacred Tuskarr Totem
200093, -- Centaur Hunting Trophy
200224, -- Mark of Sargha
201991, -- Sargha's Signet
}

 -- Profession Knowledge
local ProfessionKnowledgeIDs = {
192131, -- Valdrakken Weapon Chain
192132, -- Draconium Blade Sharpener
192443, -- Element-Infused Rocket Helmet
193891, -- Experimental Substance
193897, -- Reawakened Catalyst
193898, -- Umbral Bone Needle
193899, -- Primalweave Spindle
193900, -- Prismatic Focusing Shard
193901, -- Primal Dust
193902, -- Eroded Titan Gizmo
193903, -- Watcher Power Core
193904, -- Phoenix Feather Quill
193905, -- Iskaaran Trading Ledger
193907, -- Chipped Tyrstone
193909, -- Ancient Gem Fragments
193910, -- Molted Dragon Scales
193913, -- Preserved Animal Parts
194039, -- Heated Ore Sample
194041, -- Driftbloom Sprout
194042, -- Explorer's Banner of Herbology
194043, -- Explorer's Banner of Herbology
194044, -- Explorer's Banner of Herbology
194045, -- Explorer's Banner of Geology
194046, -- Explorer's Banner of Geology
194047, -- Explorer's Banner of Geology
194054, -- Dredged Seedling
194055, -- Primordial Soil
194061, -- Suffocating Spores
194062, -- Unyielding Stone Chunk
194063, -- Glowing Fragment
194064, -- Intricate Geode
194078, -- Perfect Draconium Scale
194079, -- Pure Serevite Nugget
194080, -- Peculiar Bud
194081, -- Mutated Root
194697, -- Draconic Treatise on Alchemy
194698, -- Draconic Treatise on Tailoring
194699, -- Draconic Treatise on Inscription
194700, -- Draconic Treatise on Leatherworking
194702, -- Draconic Treatise on Enchanting
194703, -- Draconic Treatise on Jewelcrafting
194704, -- Draconic Treatise on Herbalism
194708, -- Draconic Treatise on Mining
198156, -- Wyrmhole Generator
198454, -- Draconic Treatise on Blacksmithing
198510, -- Draconic Treatise on Engineering
198518, -- Professor Instructaur's Top Secret Guide to Blacksmithing
198519, -- Professor Instructaur's Top Secret Guide to Alchemy
198520, -- Professor Instructaur's Top Secret Guide to Enchanting
198521, -- Professor Instructaur's Top Secret Guide to Engineering
198522, -- Professor Instructaur's Top Secret Guide to Herbalism
198523, -- Professor Instructaur's Top Secret Guide to Inscription
198524, -- Professor Instructaur's Top Secret Guide to Jewelcrafting
198525, -- Professor Instructaur's Top Secret Guide to Leatherworking
198526, -- Professor Instructaur's Top Secret Guide to Mining
198528, -- Professor Instructaur's Top Secret Guide to Tailoring
198599, -- Experimental Decay Sample
198606, -- Blacksmith's Writ
198607, -- Scribe's Glyphs
198608, -- Alchemy Notes
198609, -- Tailoring Examples
198610, -- Enchanter's Script
198611, -- Engineering Details
198612, -- Jeweler's Cuts
198613, -- Leatherworking Designs
198656, -- Painter's Pretty Jewel
198658, -- Decay-Infused Tanning Oil
198659, -- Forgetful Apprentice's Tome
198660, -- Fragmented Key
198662, -- Intriguing Bolt of Blue Cloth
198663, -- Frostforged Potion
198664, -- Crystalline Overgrowth
198667, -- Spare Djaradin Tools
198669, -- How to Train Your Whelpling
198670, -- Lofty Malygite
198675, -- Lava-Infused Seed
198680, -- Decaying Brackenhide Blanket
198682, -- Alexstraszite Cluster
198683, -- Treated Hides
198684, -- Miniature Bronze Dragonflight Banner
198685, -- Well Insulated Mug
198686, -- Frosted Parchment
198687, -- Closely Guarded Shiny
198689, -- Stormbound Horn
198690, -- Decayed Scales
198692, -- Noteworthy Scrap of Carpet
198693, -- Dusty Darkmoon Card
198694, -- Enriched Earthen Shard
198696, -- Wind-Blessed Hide
198697, -- Contraband Concoction
198699, -- Mysterious Banner
198702, -- Itinerant Singed Fabric
198703, -- Sign Language Reference Sheet
198704, -- Pulsing Earth Rune
198710, -- Canteen of Suspicious Water
198711, -- Poacher's Pack
198712, -- Firewater Powder Sample
198789, -- Intact Coil Capacitor
198798, -- Flashfrozen Scroll
198799, -- Forgotten Arcane Tome
198800, -- Fractured Titanic Sphere
198836, -- Arclight Vital Correctors
198963, -- Decaying Phlegm
198964, -- Elementious Splinter
198965, -- Primeval Earth Fragment
198966, -- Molten Globule
198967, -- Primordial Aether
198968, -- Primalist Charm
198969, -- Keeper's Mark
198970, -- Infinitely Attachable Pair o' Docks
198971, -- Curious Djaradin Rune
198972, -- Draconic Glamour
198973, -- Incandescent Curio
198974, -- Elegantly Engraved Embellishment
198975, -- Ossified Hide
198976, -- Exceedingly Soft Skin
198977, -- Ohn'arhan Weave
198978, -- Stupidly Effective Stitchery
199115, -- Herbalism Field Notes
199122, -- Mining Field Notes
200677, -- Dreambloom Petal
200678, -- Dreambloom
200972, -- Dusty Blacksmith's Diagrams
200973, -- Dusty Scribe's Runic Drawings
200974, -- Dusty Alchemist's Research
200975, -- Dusty Tailor's Diagrams
200976, -- Dusty Enchanter's Research
200977, -- Dusty Engineer's Scribblings
200978, -- Dusty Jeweler's Illustrations
200979, -- Dusty Leatherworker's Diagrams
200980, -- Dusty Herbalist's Notes
200981, -- Dusty Miner's Notes
201003, -- Furry Gloop
201004, -- Ancient Spear Shards
201005, -- Curious Ingots
201006, -- Draconic Flux
201007, -- Ancient Monument
201008, -- Molten Ingot
201009, -- Falconer Gauntlet Drawings
201010, -- Qalashi Weapon Diagram
201011, -- Spelltouched Tongs
201012, -- Enchanted Debris
201013, -- Faintly Enchanted Remains
201014, -- Boomthyr Rocket
201015, -- Counterfeit Darkmoon Deck
201016, -- Harmonic Crystal Harmonizer
201017, -- Igneous Gem
201018, -- Well-Danced Drum
201019, -- Ancient Dragonweave Bolt
201020, -- Silky Surprise
201268, -- Rare Blacksmith's Diagrams
201269, -- Rare Scribe's Runic Drawings
201270, -- Rare Alchemist's Research
201271, -- Rare Tailor's Diagrams
201272, -- Rare Enchanter's Research
201273, -- Rare Engineer's Scribblings
201274, -- Rare Jeweler's Illustrations
201275, -- Rare Leatherworker's Diagrams
201276, -- Rare Herbalist's Notes
201277, -- Rare Miner's Notes
201279, -- Ancient Blacksmith's Diagrams
201280, -- Ancient Scribe's Runic Drawings
201281, -- Ancient Alchemist's Research
201282, -- Ancient Tailor's Diagrams
201283, -- Ancient Enchanter's Research
201284, -- Ancient Engineer's Scribblings
201285, -- Ancient Jeweler's Illustrations
201286, -- Ancient Leatherworker's Diagrams
201287, -- Ancient Herbalist's Notes
201288, -- Ancient Miner's Notes
201300, -- Iridescent Ore Fragments
201301, -- Iridescent Ore
201356, -- Glimmer of Fire
201357, -- Glimmer of Frost
201358, -- Glimmer of Air
201359, -- Glimmer of Earth
201360, -- Glimmer of Order
201700, -- Notebook of Crafting Knowledge
201705, -- Notebook of Crafting Knowledge
201706, -- Notebook of Crafting Knowledge
201708, -- Notebook of Crafting Knowledge
201709, -- Notebook of Crafting Knowledge
201710, -- Notebook of Crafting Knowledge
201711, -- Notebook of Crafting Knowledge
201712, -- Notebook of Crafting Knowledge
201713, -- Notebook of Crafting Knowledge
201715, -- Notebook of Crafting Knowledge
201716, -- Notebook of Crafting Knowledge
201717, -- Notebook of Crafting Knowledge
202011, -- Elementally-Charged Stone
202014, -- Infused Pollen
}

 -- Cooking
local CookingIDs = {
194730, -- Scalebelly Mackerel
194966, -- Thousandbite Piranha
194967, -- Aileron Seamoth
194968, -- Cerulean Spinefish
194969, -- Temporal Dragonhead
194970, -- Islefin Dorado
197741, -- Maybe Meat
197742, -- Ribbed Mollusk Meat
197743, -- Waterfowl Filet
197744, -- Hornswog Hunk
197745, -- Basilisk Eggs
197746, -- Bruffalon Flank
197747, -- Mighty Mammoth Ribs
197748, -- Burly Bear Haunch
197749, -- Ohn'ahran Potato
197750, -- Three-Cheese Blend
197751, -- Pastry Packets
197752, -- Conveniently Packaged Ingredients
197753, -- Thaldraszian Cocoa Powder
197754, -- Salt Deposit
197755, -- Lava Beetle
197756, -- Pebbled Rock Salts
197757, -- Assorted Exotic Spices
198395, -- Dull Spined Clam
199063, -- Salted Fish Scraps
199100, -- Peppersmelt
199101, -- Dried Wyldermane Kelp
199102, -- Hunk o' Blubber
199103, -- Nappa's Famous Tea
199104, -- Piping-Hot Orca Milk
199105, -- Ancheevy
199106, -- Tiny Leviathan Bone
199205, -- Manasucker
199207, -- Iceback Sculpin
199208, -- Grungle
199212, -- Clubfish
199213, -- Lakkamuk Blenny
199344, -- Magma Thresher
199345, -- Rimefin Tuna
199346, -- Rotten Rimefin Tuna
199832, -- Smoked Seaviper
199833, -- Dragonhead Eel
199834, -- Pulpy Seagrass
199835, -- Torga's Braid
200061, -- Prismatic Leaper
200074, -- Frosted Rimefin Tuna
}

 -- Darkmoon Cards
local DarkmoonCardsIDs = {
194785, -- Ace of Fire
194786, -- Two of Fire
194787, -- Three of Fire
194788, -- Four of Fire
194789, -- Five of Fire
194790, -- Six of Fire
194791, -- Seven of Frost
194792, -- Eight of Fire
194793, -- Ace of Frost
194794, -- Two of Frost
194795, -- Three of Frost
194796, -- Four of Frost
194797, -- Five of Frost
194798, -- Six of Frost
194799, -- Seven of Fire
194800, -- Eight of Frost
194801, -- Ace of Air
194802, -- Two of Air
194803, -- Three of Air
194804, -- Four of Air
194805, -- Five of Air
194806, -- Six of Air
194807, -- Seven of Air
194808, -- Eight of Air
194809, -- Ace of Earth
194810, -- Two of Earth
194811, -- Three of Earth
194812, -- Four of Earth
194813, -- Five of Earth
194814, -- Six of Earth
194815, -- Seven of Earth
194816, -- Eight of Earth
194827, -- Bundle O' Cards: Dragon Isles
198614, -- Soggy Clump of Darkmoon Cards
}

 -- PreEvent Currency
local PreEventCurrencyIDs = {
199211, -- Primeval Essence
199836, -- Dimmed Primeval Fire
199837, -- Dimmed Primeval Earth
199838, -- Dimmed Primeval Storm
199839, -- Dimmed Primeval Water
}

 -- Engineering
local EngineeringIDs = {
198183, -- Handful of Serevite Bolts
198184, -- Handful of Serevite Bolts
198185, -- Handful of Serevite Bolts
198186, -- Shock-Spring Coil
198187, -- Shock-Spring Coil
198188, -- Shock-Spring Coil
198189, -- Everburning Blasting Powder
198190, -- Everburning Blasting Powder
198191, -- Everburning Blasting Powder
198192, -- Greased-Up Gears
198193, -- Greased-Up Gears
198194, -- Greased-Up Gears
198195, -- Arclight Capacitor
198196, -- Arclight Capacitor
198197, -- Arclight Capacitor
198198, -- Reinforced Machine Chassis
198199, -- Reinforced Machine Chassis
198200, -- Reinforced Machine Chassis
198201, -- Assorted Safety Fuses
198202, -- Assorted Safety Fuses
198203, -- Assorted Safety Fuses
201832, -- Smudged Lens
}

 -- Alchemy
local AlchemyIDs = {
191474, -- Draconic Vial
191475, -- Draconic Vial
191476, -- Draconic Vial
}

 -- Inscription
local InscriptionIDs = {
194751, -- Blazing Ink
194752, -- Blazing Ink
194754, -- Cosmic Ink
194755, -- Cosmic Ink
194756, -- Cosmic Ink
194758, -- Flourishing Ink
194760, -- Burnished Ink
194761, -- Burnished Ink
194767, -- Chilled Rune
194768, -- Chilled Rune
194784, -- Glittering Parchment
194824, -- Chirping Rune
194825, -- Chirping Rune
194826, -- Chirping Rune
194846, -- Blazing Ink
194850, -- Flourishing Ink
194852, -- Flourishing Ink
194855, -- Burnished Ink
194856, -- Serene Ink
194857, -- Serene Ink
194858, -- Serene Ink
194859, -- Chilled Rune
194862, -- Runed Writhebark
194863, -- Runed Writhebark
194864, -- Runed Writhebark
198412, -- Serene Pigment
198413, -- Serene Pigment
198414, -- Serene Pigment
198415, -- Flourishing Pigment
198416, -- Flourishing Pigment
198417, -- Flourishing Pigment
198418, -- Blazing Pigment
198419, -- Blazing Pigment
198420, -- Blazing Pigment
198421, -- Shimmering Pigment
198422, -- Shimmering Pigment
198423, -- Shimmering Pigment
}

 -- Treasure Sacks
local TreasureSacksIDs = {
199341, -- Regurgitated Sac of Swog Treasures
199342, -- Weighted Sac of Swog Treasures
199343, -- ERROR
202102, -- Immaculate Sac of Swog Treasures
202103, -- ERROR
202104, -- ERROR
}

 -- Leather
local LeatherIDs = {
193208, -- Resilient Leather
193210, -- Resilient Leather
193211, -- Resilient Leather
193213, -- Adamant Scales
193214, -- Adamant Scales
193215, -- Adamant Scales
193216, -- Dense Hide
193217, -- Dense Hide
193218, -- Dense Hide
193222, -- Lustrous Scaled Hide
193223, -- Lustrous Scaled Hide
193224, -- Lustrous Scaled Hide
193226, -- Stonecrust Hide
193227, -- Stonecrust Hide
193228, -- Stonecrust Hide
193229, -- Mireslush Hide
193230, -- Mireslush Hide
193231, -- Mireslush Hide
193232, -- Deathchill Hide
193233, -- Deathchill Hide
193234, -- Deathchill Hide
193236, -- Infurious Hide
193237, -- Infurious Hide
193238, -- Infurious Hide
193239, -- Drygrate Scales
193240, -- Drygrate Scales
193241, -- Drygrate Scales
193242, -- Earthshine Scales
193243, -- Earthshine Scales
193244, -- Earthshine Scales
193245, -- Frostbite Scales
193246, -- Frostbite Scales
193247, -- Frostbite Scales
193248, -- Infurious Scales
193249, -- Infurious Scales
193250, -- Infurious Scales
193251, -- Crystalspine Fur
193252, -- Salamanther Scales
193253, -- Cacophonous Thunderscale
193254, -- Rockfang Leather
193255, -- Pristine Vorquin Horn
193256, -- Windsong Plumage
193258, -- Fire-Infused Hide
193259, -- Flawless Proto Dragon Scale
193261, -- Bite-Sized Morsel
193262, -- Exceptional Morsel
197735, -- Finished Prototype Explorer's Barding
197736, -- Finished Prototype Regal Barding
}

 -- Jewelcrafting
local JewelcraftingIDs = {
192833, -- Misshapen Filigree
192834, -- Shimmering Clasp
192835, -- Shimmering Clasp
192836, -- Shimmering Clasp
192837, -- Queen's Ruby
192838, -- Queen's Ruby
192839, -- Queen's Ruby
192840, -- Mystic Sapphire
192841, -- Mystic Sapphire
192842, -- Mystic Sapphire
192843, -- Vibrant Emerald
192844, -- Vibrant Emerald
192845, -- Vibrant Emerald
192846, -- Sundered Onyx
192847, -- Sundered Onyx
192848, -- Sundered Onyx
192849, -- Eternity Amber
192850, -- Eternity Amber
192851, -- Eternity Amber
192852, -- Alexstraszite
192853, -- Alexstraszite
192855, -- Alexstraszite
192856, -- Malygite
192857, -- Malygite
192858, -- Malygite
192859, -- Ysemerald
192860, -- Ysemerald
192861, -- Ysemerald
192862, -- Neltharite
192863, -- Neltharite
192865, -- Neltharite
192866, -- Nozdorite
192867, -- Nozdorite
192868, -- Nozdorite
192869, -- Illimited Diamond
192870, -- Illimited Diamond
192871, -- Illimited Diamond
192872, -- Fractured Glass
192876, -- Frameless Lens
192877, -- Frameless Lens
192878, -- Frameless Lens
192880, -- Crumbled Stone
192883, -- Glossy Stone
192884, -- Glossy Stone
192885, -- Glossy Stone
192888, -- Queen's Gift
192889, -- Dreamer's Vision
192890, -- Keeper's Glory
192891, -- Earthwarden's Prize
192892, -- Timewatcher's Patience
192893, -- Jeweled Dragon's Heart
192894, -- Blotting Sand
192895, -- Blotting Sand
192896, -- Blotting Sand
192897, -- Pounce
192898, -- Pounce
192899, -- Pounce
193029, -- Projection Prism
193030, -- Projection Prism
193031, -- Projection Prism
193368, -- Silken Gemdust
193369, -- Silken Gemdust
193370, -- Silken Gemdust
198397, -- Rainbow Pearl
200156, -- Amethyzarite Geode
202048, -- Queen's Gift
202049, -- Dreamer's Vision
202050, -- Keeper's Glory
202051, -- Earthwarden's Prize
202052, -- Timewatcher's Patience
202053, -- ERROR
202054, -- Queen's Gift
202055, -- Dreamer's Vision
202056, -- Keeper's Glory
202057, -- Earthwarden's Prize
202058, -- Timewatcher's Patience
202059, -- ERROR
}

 -- Mining
local MiningIDs = {
188658, -- Draconium Ore
189143, -- Draconium Ore
189541, -- Primal Molten Alloy
189542, -- Primal Molten Alloy
189543, -- Primal Molten Alloy
190311, -- Draconium Ore
190312, -- Khaz'gorite Ore
190313, -- Khaz'gorite Ore
190314, -- Khaz'gorite Ore
190394, -- Serevite Ore
190395, -- Serevite Ore
190396, -- Serevite Ore
190452, -- Primal Flux
190530, -- Frostfire Alloy
190531, -- Frostfire Alloy
190532, -- Frostfire Alloy
190533, -- Obsidian Seared Alloy
190534, -- Obsidian Seared Alloy
190535, -- Obsidian Seared Alloy
190536, -- Infurious Alloy
190537, -- Infurious Alloy
190538, -- Infurious Alloy
194545, -- Prismatic Ore
}

 -- Elemental Trade Goods
local ElementalTradeGoodsIDs = {
190315, -- Rousing Earth
190316, -- Awakened Earth
190320, -- Rousing Fire
190321, -- Awakened Fire
190322, -- Rousing Order
190324, -- Awakened Order
190326, -- Rousing Air
190327, -- Awakened Air
190328, -- Rousing Frost
190329, -- Awakened Frost
190330, -- Rousing Decay
190331, -- Awakened Decay
190450, -- Awakened Ire
190451, -- Rousing Ire
}

 -- PreEvent Gear
local PreEventGearIDs = {
199348, -- Cloudburst Robes
199349, -- Cloudburst Slippers
199350, -- Cloudburst Mitts
199351, -- Cloudburst Hood
199352, -- Cloudburst Breeches
199353, -- Cloudburst Mantle
199354, -- Cloudburst Sash
199355, -- Cloudburst Bindings
199356, -- Dust Devil Raiment
199357, -- Dust Devil Treads
199358, -- Dust Devil Gloves
199359, -- Dust Devil Mask
199360, -- Dust Devil Leggings
199361, -- Dust Devil Epaulets
199362, -- Dust Devil Cincture
199363, -- Dust Devil Wristbands
199364, -- Cyclonic Chainmail
199365, -- Cyclonic Striders
199366, -- Cyclonic Gauntlets
199367, -- Cyclonic Cowl
199368, -- Cyclonic Kilt
199369, -- Cyclonic Spaulders
199370, -- Cyclonic Cinch
199371, -- Cyclonic Bracers
199372, -- Firestorm Chestplate
199373, -- Firestorm Stompers
199374, -- Firestorm Crushers
199375, -- Firestorm Greathelm
199376, -- Firestorm Greaves
199377, -- Firestorm Pauldrons
199378, -- Firestorm Girdle
199379, -- Firestorm Vambraces
199380, -- Cyclonic Drape
199381, -- Seal of Elemental Disasters
199382, -- Catastrophe Signet
199383, -- Torc of Calamities
199384, -- Cloudburst Wrap
199385, -- Dust Devil Cloak
199386, -- Firestorm Cape
199399, -- Galerider Poleaxe
199400, -- Squallbreaker Greatsword
199401, -- Stormbender Scroll
199402, -- Galepiercer Ballista
199403, -- Stormbender Maul
199404, -- Squallbreaker Shield
199405, -- Stormbender Rod
199406, -- Galerider Mallet
199407, -- Galerider Shank
199408, -- Squallbreaker Longblade
199409, -- Stormbender Saber
199416, -- Galerider Crescent
199555, -- Versatile Storm Lure
199645, -- Storm Hunter's Insignia
}

 -- General Crafting
local GeneralCraftingIDs = {
194785, -- Ace of Fire
194786, -- Two of Fire
194787, -- Three of Fire
194788, -- Four of Fire
194789, -- Five of Fire
194790, -- Six of Fire
194791, -- Seven of Frost
194792, -- Eight of Fire
194793, -- Ace of Frost
194794, -- Two of Frost
194795, -- Three of Frost
194796, -- Four of Frost
194797, -- Five of Frost
194798, -- Six of Frost
194799, -- Seven of Fire
194800, -- Eight of Frost
194801, -- Ace of Air
194802, -- Two of Air
194803, -- Three of Air
194804, -- Four of Air
194805, -- Five of Air
194806, -- Six of Air
194807, -- Seven of Air
194808, -- Eight of Air
194809, -- Ace of Earth
194810, -- Two of Earth
194811, -- Three of Earth
194812, -- Four of Earth
194813, -- Five of Earth
194814, -- Six of Earth
194815, -- Seven of Earth
194816, -- Eight of Earth
194827, -- Bundle O' Cards: Dragon Isles
198614, -- Soggy Clump of Darkmoon Cards
}

 -- Fortune Cards
local FortuneCardsIDs = {
194829, -- Fated Fortune Card
199114, -- Fated Fortune Card
199116, -- Fated Fortune Card
199117, -- Fated Fortune Card
199118, -- Fated Fortune Card
199119, -- Fated Fortune Card
199120, -- Fated Fortune Card
199121, -- Fated Fortune Card
199123, -- Fated Fortune Card
199124, -- Fated Fortune Card
199125, -- Fated Fortune Card
199126, -- Fated Fortune Card
199127, -- Fated Fortune Card
199129, -- Fated Fortune Card
199130, -- Fated Fortune Card
199131, -- Fated Fortune Card
199132, -- Fated Fortune Card
199133, -- Fated Fortune Card
199134, -- Fated Fortune Card
199135, -- Fated Fortune Card
199136, -- Fated Fortune Card
199137, -- Fated Fortune Card
199138, -- Fated Fortune Card
199139, -- Fated Fortune Card
199140, -- Fated Fortune Card
199141, -- Fated Fortune Card
199142, -- Fated Fortune Card
199143, -- Fated Fortune Card
199144, -- Fated Fortune Card
199145, -- Fated Fortune Card
199146, -- Fated Fortune Card
199147, -- Fated Fortune Card
199148, -- Fated Fortune Card
199149, -- Fated Fortune Card
199150, -- Fated Fortune Card
199151, -- Fated Fortune Card
199152, -- Fated Fortune Card
199153, -- Fated Fortune Card
199154, -- Fated Fortune Card
199155, -- Fated Fortune Card
199156, -- Fated Fortune Card
199157, -- Fated Fortune Card
199158, -- Fated Fortune Card
199159, -- Fated Fortune Card
199160, -- Fated Fortune Card
199161, -- Fated Fortune Card
199162, -- Fated Fortune Card
199163, -- Fated Fortune Card
199164, -- Fated Fortune Card
199165, -- Fated Fortune Card
199166, -- Fated Fortune Card
199167, -- Fated Fortune Card
199168, -- Fated Fortune Card
199169, -- Fated Fortune Card
199170, -- Fated Fortune Card
}

 -- Cloth
local ClothIDs = {
192095, -- Spool of Wilderthread
192096, -- Spool of Wilderthread
192097, -- Spool of Wilderthread
193050, -- Tattered Wildercloth
193053, -- Contoured Fowlfeather
193922, -- Wildercloth
193923, -- Decayed Wildercloth
193924, -- Frostbitten Wildercloth
193925, -- Singed Wildercloth
193926, -- Wildercloth Bolt
193927, -- Wildercloth Bolt
193928, -- Wildercloth Bolt
193929, -- Vibrant Wildercloth Bolt
193930, -- Vibrant Wildercloth Bolt
193931, -- Vibrant Wildercloth Bolt
193932, -- Infurious Wildercloth Bolt
193933, -- Infurious Wildercloth Bolt
193934, -- Infurious Wildercloth Bolt
193935, -- Chronocloth Bolt
193936, -- Chronocloth Bolt
193937, -- Chronocloth Bolt
193938, -- Azureweave Bolt
193939, -- Azureweave Bolt
193940, -- Azureweave Bolt
}



local function MatchIDs_Init(self)
    wipe(Result)

    if self.db.profile.moveHerbs then
        if self.db.profile.showcoloredCategories then
            Result["|cff00ff36Herbs|r"] = AddToSet(HerbsIDs)
        else
            Result[unescape("|cff00ff36Herbs|r")] = AddToSet(HerbsIDs)
        end
    end

    if self.db.profile.moveDrakewatcherManuscripts then
        if self.db.profile.showcoloredCategories then
            Result["|cff33937fDrakewatcher Manuscripts|r"] = AddToSet(DrakewatcherManuscriptsIDs)
        else
            Result[unescape("|cff33937fDrakewatcher Manuscripts|r")] = AddToSet(DrakewatcherManuscriptsIDs)
        end
    end

    if self.db.profile.moveEnchanting then
        if self.db.profile.showcoloredCategories then
            Result["|cff96ff00Enchanting|r"] = AddToSet(EnchantingIDs)
        else
            Result[unescape("|cff96ff00Enchanting|r")] = AddToSet(EnchantingIDs)
        end
    end

    if self.db.profile.moveReputationItems then
        if self.db.profile.showcoloredCategories then
            Result["|cff1eff00Reputation Items|r"] = AddToSet(ReputationItemsIDs)
        else
            Result[unescape("|cff1eff00Reputation Items|r")] = AddToSet(ReputationItemsIDs)
        end
    end

    if self.db.profile.moveProfessionKnowledge then
        if self.db.profile.showcoloredCategories then
            Result["|cff33937fProfession Knowledge|r"] = AddToSet(ProfessionKnowledgeIDs)
        else
            Result[unescape("|cff33937fProfession Knowledge|r")] = AddToSet(ProfessionKnowledgeIDs)
        end
    end

    if self.db.profile.moveCooking then
        if self.db.profile.showcoloredCategories then
            Result["|cffff0072Cooking|r"] = AddToSet(CookingIDs)
        else
            Result[unescape("|cffff0072Cooking|r")] = AddToSet(CookingIDs)
        end
    end

    if self.db.profile.moveDarkmoonCards then
        if self.db.profile.showcoloredCategories then
            Result["|cff48aa00Darkmoon Cards|r"] = AddToSet(DarkmoonCardsIDs)
        else
            Result[unescape("|cff48aa00Darkmoon Cards|r")] = AddToSet(DarkmoonCardsIDs)
        end
    end

    if self.db.profile.movePreEventCurrency then
        if self.db.profile.showcoloredCategories then
            Result["|cff0060a2PreEvent Currency|r"] = AddToSet(PreEventCurrencyIDs)
        else
            Result[unescape("|cff0060a2PreEvent Currency|r")] = AddToSet(PreEventCurrencyIDs)
        end
    end

    if self.db.profile.moveEngineering then
        if self.db.profile.showcoloredCategories then
            Result["|cff787878Engineering|r"] = AddToSet(EngineeringIDs)
        else
            Result[unescape("|cff787878Engineering|r")] = AddToSet(EngineeringIDs)
        end
    end

    if self.db.profile.moveAlchemy then
        if self.db.profile.showcoloredCategories then
            Result["|cff91ffe9Alchemy|r"] = AddToSet(AlchemyIDs)
        else
            Result[unescape("|cff91ffe9Alchemy|r")] = AddToSet(AlchemyIDs)
        end
    end

    if self.db.profile.moveInscription then
        if self.db.profile.showcoloredCategories then
            Result["|cff4dfaf8Inscription|r"] = AddToSet(InscriptionIDs)
        else
            Result[unescape("|cff4dfaf8Inscription|r")] = AddToSet(InscriptionIDs)
        end
    end

    if self.db.profile.moveTreasureSacks then
        if self.db.profile.showcoloredCategories then
            Result["|cfffff000Treasure Sacks|r"] = AddToSet(TreasureSacksIDs)
        else
            Result[unescape("|cfffff000Treasure Sacks|r")] = AddToSet(TreasureSacksIDs)
        end
    end

    if self.db.profile.moveLeather then
        if self.db.profile.showcoloredCategories then
            Result["|cff865b00Leather|r"] = AddToSet(LeatherIDs)
        else
            Result[unescape("|cff865b00Leather|r")] = AddToSet(LeatherIDs)
        end
    end

    if self.db.profile.moveJewelcrafting then
        if self.db.profile.showcoloredCategories then
            Result["|cff514dfaJewelcrafting|r"] = AddToSet(JewelcraftingIDs)
        else
            Result[unescape("|cff514dfaJewelcrafting|r")] = AddToSet(JewelcraftingIDs)
        end
    end

    if self.db.profile.moveMining then
        if self.db.profile.showcoloredCategories then
            Result["|cff898396Mining|r"] = AddToSet(MiningIDs)
        else
            Result[unescape("|cff898396Mining|r")] = AddToSet(MiningIDs)
        end
    end

    if self.db.profile.moveElementalTradeGoods then
        if self.db.profile.showcoloredCategories then
            Result["|cff644bffElemental Trade Goods|r"] = AddToSet(ElementalTradeGoodsIDs)
        else
            Result[unescape("|cff644bffElemental Trade Goods|r")] = AddToSet(ElementalTradeGoodsIDs)
        end
    end

    if self.db.profile.movePreEventGear then
        if self.db.profile.showcoloredCategories then
            Result["|cff0050a2PreEvent Gear|r"] = AddToSet(PreEventGearIDs)
        else
            Result[unescape("|cff0050a2PreEvent Gear|r")] = AddToSet(PreEventGearIDs)
        end
    end

    if self.db.profile.moveGeneralCrafting then
        if self.db.profile.showcoloredCategories then
            Result["|cff51479cGeneral Crafting|r"] = AddToSet(GeneralCraftingIDs)
        else
            Result[unescape("|cff51479cGeneral Crafting|r")] = AddToSet(GeneralCraftingIDs)
        end
    end

    if self.db.profile.moveFortuneCards then
        if self.db.profile.showcoloredCategories then
            Result["|cff6cff00Fortune Cards|r"] = AddToSet(FortuneCardsIDs)
        else
            Result[unescape("|cff6cff00Fortune Cards|r")] = AddToSet(FortuneCardsIDs)
        end
    end

    if self.db.profile.moveCloth then
        if self.db.profile.showcoloredCategories then
            Result["|cffff7e00Cloth|r"] = AddToSet(ClothIDs)
        else
            Result[unescape("|cffff7e00Cloth|r")] = AddToSet(ClothIDs)
        end
    end



    return Result
end

local setFilter = AdiBags:RegisterFilter("Dragonflight", 98, "ABEvent-1.0")
setFilter.uiName = "|cffA00000Dragonflight|r"
setFilter.uiDesc = "Items from the Dragonflight\n|cffFFD800Filter version: 1.1.8|r"

function setFilter:OnInitialize()
    self.db = AdiBags.db:RegisterNamespace("Dragonflight", {
        profile = {
            
            moveHerbs = false,
            moveDrakewatcherManuscripts = true,
            moveEnchanting = false,
            moveReputationItems = true,
            moveProfessionKnowledge = true,
            moveCooking = false,
            moveDarkmoonCards = true,
            movePreEventCurrency = true,
            moveEngineering = false,
            moveAlchemy = false,
            moveInscription = false,
            moveTreasureSacks = true,
            moveLeather = false,
            moveJewelcrafting = false,
            moveMining = false,
            moveElementalTradeGoods = true,
            movePreEventGear = true,
            moveGeneralCrafting = false,
            moveFortuneCards = true,
            moveCloth = false,
            showcoloredCategories = true,
        }
    })
end

function setFilter:Update()
    MatchIDs = nil
    self:SendMessage("AdiBags_FiltersChanged")
end

function setFilter:OnEnable()
    AdiBags:UpdateFilters()
end

function setFilter:OnDisable()
    AdiBags:UpdateFilters()
end

function setFilter:Filter(slotData)
    MatchIDs = MatchIDs or MatchIDs_Init(self)
    for i, name in pairs(MatchIDs) do
        -- Override Method
        if MatchIDs[i]['override'] then
            slotData['loc'] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
            if slotData['loc']  and slotData['loc']:IsValid() then
                if MatchIDs[i]['override_method'](slotData.loc) then
                    return i
                end
            end

        -- Bonus Condition (triggers when bonus condition is not fulfilled)
        elseif MatchIDs[i]['bonus_condition'] then
            if name[slotData.itemId] then
                slotData['loc'] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
                if slotData['loc'] and slotData['loc']:IsValid() then
                    if not MatchIDs[i]['bonus_condition_method'](slotData.loc) then -- THERE IS A NOT HERE!
                        return i
                    end
                end
            end

        -- Standard ID Matching
        elseif name[slotData.itemId] then
            return i
        end
    end
end

function setFilter:GetOptions()
    return {
        moveHerbs = {
            name = "Herbs",
            desc = "Crafting Reagents of the 'Herbs' category",
            type = "toggle",
            order = 10
        },

        moveDrakewatcherManuscripts = {
            name = "Drakewatcher Manuscripts",
            desc = "Drakewatcher Manuscripts for learning new customizations for your Dragonriding mounts",
            type = "toggle",
            order = 20
        },

        moveEnchanting = {
            name = "Enchanting",
            desc = "Crafting Reagents of the 'Enchanting' category",
            type = "toggle",
            order = 30
        },

        moveReputationItems = {
            name = "Reputation Items",
            desc = "Contains Items which can be directly traded in for reputation/renown, as well as items needed for Wrathion & Sabellian",
            type = "toggle",
            order = 40
        },

        moveProfessionKnowledge = {
            name = "Profession Knowledge",
            desc = "Items that provide profession knowledge",
            type = "toggle",
            order = 50
        },

        moveCooking = {
            name = "Cooking",
            desc = "Crafting Reagents of the 'Cooking' category",
            type = "toggle",
            order = 60
        },

        moveDarkmoonCards = {
            name = "Darkmoon Cards",
            desc = "Darkmoon Cards",
            type = "toggle",
            order = 70
        },

        movePreEventCurrency = {
            name = "PreEvent Currency",
            desc = "Currency-like items dropped in the Dragonflight Pre-Patch Event",
            type = "toggle",
            order = 80
        },

        moveEngineering = {
            name = "Engineering",
            desc = "Crafting Reagents of the 'Engineering' category",
            type = "toggle",
            order = 90
        },

        moveAlchemy = {
            name = "Alchemy",
            desc = "Crafting Reagents of the 'Alchemy' category (flasks only, you may also want to enable Herbs)",
            type = "toggle",
            order = 100
        },

        moveInscription = {
            name = "Inscription",
            desc = "Crafting Reagents of the 'Inscription' category",
            type = "toggle",
            order = 110
        },

        moveTreasureSacks = {
            name = "Treasure Sacks",
            desc = "Treasure Sacks",
            type = "toggle",
            order = 120
        },

        moveLeather = {
            name = "Leather",
            desc = "Crafting Reagents of the 'Leather' category",
            type = "toggle",
            order = 130
        },

        moveJewelcrafting = {
            name = "Jewelcrafting",
            desc = "Crafting Reagents of the 'Jewelcrafting' category",
            type = "toggle",
            order = 140
        },

        moveMining = {
            name = "Mining",
            desc = "Crafting Reagents of the 'Mining' category",
            type = "toggle",
            order = 150
        },

        moveElementalTradeGoods = {
            name = "Elemental Trade Goods",
            desc = "Awakened and Rousing Elemental Trade Goods",
            type = "toggle",
            order = 160
        },

        movePreEventGear = {
            name = "PreEvent Gear",
            desc = "Gear dropped or bought in the Dragonflight Pre-Patch Event",
            type = "toggle",
            order = 170
        },

        moveGeneralCrafting = {
            name = "General Crafting",
            desc = "General Crafting Reagents, used by multiple professions",
            type = "toggle",
            order = 180
        },

        moveFortuneCards = {
            name = "Fortune Cards",
            desc = "Fortune Cards",
            type = "toggle",
            order = 190
        },

        moveCloth = {
            name = "Cloth",
            desc = "Crafting Reagents of the 'Cloth' category",
            type = "toggle",
            order = 200
        },

        showcoloredCategories = {
            name = "|cffff98abC|cffffa094o|cffffa77el|cffffaf67o|cfffebf71r|cfffecf7be|cfffddf85d|cffe0d988 |cffc3d38bC|cffa6cd8ea|cff9bccaet|cff8fcbcde|cff95bad2g|cff9aa9d7o|cffa098dcr|cffae98dci|cffbd98dce|cffcb98dcs|r",
            desc = "Should Categories be colored?",
            type = "toggle",
            order = 210
        },


    },
    AdiBags:GetOptionHandler(self, false, function ()
        return self:Update()
    end)
end
